@@ -3,4 +3,6 @@ from . import bwt
 from . import fmindex
 from . import waveletmatrix
 from . import binaryio
+from . import query
+from . import queryparser
 from .oktavia import *
